@@ -1,9 +1,10 @@
+import os.path
 import subprocess
 from typing import List
 
 
-def run_command(target: str, args: List[str]) -> int:
-    cmd = ['java', '-jar', target] + args
+def run_command(filename: str, cache_dir: str, args: List[str]) -> int:
+    cmd = ['java', '-jar', os.path.join(cache_dir, filename)] + args
 
     result = subprocess.run(
         args=cmd,
@@ -11,10 +12,10 @@ def run_command(target: str, args: List[str]) -> int:
         encoding="UTF-8",
     )
 
-    output = result.stdout
     exit_code = result.returncode
-
+    output = result.stdout or result.stderr
     print(output)
+
     if result.check_returncode is not None:
         print(
             "Process finished with exit code {exit_code}".format(
