@@ -5,6 +5,21 @@ from typing import List
 from typing import Optional
 from typing import Sequence
 
+from checkstyle import __version__
+from checkstyle import default_runtime
+
+
+def convert_args_dict_to_list(kwargs) -> List[str]:
+    result = []
+    for k, v in kwargs.items():
+        result.append("-"+k[0])
+        result.append(v)
+    return result
+
+
+def _is_google_or_sun(config: str) -> bool:
+    return config == 'google' or config == 'sun'
+
 
 class Parser:
     _parser = ArgumentParser()
@@ -18,10 +33,15 @@ class Parser:
             help="checkstyle configuration file",
         )
         self._parser.add_argument(
-            "-v",
+            "-V",
             "--version",
+            action='version',
+            version=f'checkstyle-cli {__version__}',
+        )
+        self._parser.add_argument(
+            "--runtime-version",
             type=str,
-            default="latest",
+            default=default_runtime,
             help="checkstyle version",
         )
         self._parser.add_argument(
@@ -33,19 +53,9 @@ class Parser:
         args, unknown = self._parser.parse_known_args(argv)
         args_dict = vars(args)
 
-        if self._is_google_or_sun(args_dict['config']):
+        if _is_google_or_sun(args_dict['config']):
             args_dict['config'] = "/{name}_checks.xml".format(
                 name=args_dict['config'],
             )
 
         return args_dict
-
-    def convert_args_dict_to_list(self, kwargs) -> List[str]:
-        result = []
-        for k, v in kwargs.items():
-            result.append("-"+k[0])
-            result.append(v)
-        return result
-
-    def _is_google_or_sun(self, config: str) -> bool:
-        return config == 'google' or config == 'sun'
